pub struct Service { /* private fields */ }Expand description
Cloneable Telegram session coordination service.
Implementations
Sourceimpl Service
impl Service
Sourcepub fn new(telegram: Service, directory: Arc<Directory>) -> Self
pub fn new(telegram: Service, directory: Arc<Directory>) -> Self
Constructs coordination over the existing transport and Kennedy identity owner.
Sourcepub async fn send_private(&self, request: PrivateDelivery) -> Result<String>
pub async fn send_private(&self, request: PrivateDelivery) -> Result<String>
Sends one complete cold private delivery in caller-supplied order.
Sourcepub async fn send_group(&self, request: GroupDelivery) -> Result<String>
pub async fn send_group(&self, request: GroupDelivery) -> Result<String>
Sends one complete group delivery after fresh root and eligibility resolution.